Package: bigrquery
Title: An Interface to Google's 'BigQuery' 'API'
Version: 1.3.1
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@rstudio.com", c("aut", "cre"),
      comment = c(ORCID = "0000-0003-4757-117X")),
    person("Jennifer", "Bryan", , "jenny@rstudio.com", "aut",
      comment = c(ORCID = "0000-0002-6983-2759")),
    person("Kungliga Tekniska Högskolan", role = "ctb", comment = "strptime implementation"),
    person("The NetBSD Foundation, Inc.", role = "ctb", comment = "gmtime implementation"),
    person("RStudio", role = c("cph", "fnd"))
    )
Description: Easily talk to Google's 'BigQuery' database from R.
License: GPL-3
URL: https://github.com/rstats-db/bigrquery
BugReports: https://github.com/rstats-db/bigrquery/issues
Depends: R (>= 3.2)
Imports: assertthat, bit64, curl, DBI, gargle (>= 0.5.0), glue (>=
        1.3.0), httr, jsonlite, methods, prettyunits, progress, Rcpp,
        rlang, tibble
Suggests: covr, DBItest, dbplyr (>= 1.3.0), dplyr (>= 0.7.0), hms,
        readr, sodium, testthat (>= 2.1.0), withr
LinkingTo: progress, rapidjsonr, Rcpp
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
Collate: 'RcppExports.R' 'bigrquery.R' 'bq-auth.R' 'bq-dataset.R'
        'bq-download.R' 'bq-field.R' 'bq-job.R' 'bq-param.R'
        'bq-parse.R' 'bq-perform.R' 'bq-project.R' 'bq-projects.R'
        'bq-query.R' 'bq-refs.R' 'bq-request.R' 'bq-table.R'
        'bq-test.R' 'camelCase.R' 'dbi-driver.R' 'dbi-connection.R'
        'dbi-result.R' 'dplyr.R' 'gs-object.R' 'old-auth.R'
        'old-dataset.R' 'old-id.R' 'old-job-extract.R'
        'old-job-query.R' 'old-job-upload.R' 'old-job.R'
        'old-project.R' 'old-projects.R' 'old-query.R' 'old-table.R'
        'old-tabledata.R' 'utils.R' 'zzz.R'
NeedsCompilation: yes
Packaged: 2020-05-15 15:06:42 UTC; hadley
Author: Hadley Wickham [aut, cre] (<https://orcid.org/0000-0003-4757-117X>),
  Jennifer Bryan [aut] (<https://orcid.org/0000-0002-6983-2759>),
  Kungliga Tekniska Högskolan [ctb] (strptime implementation),
  The NetBSD Foundation, Inc. [ctb] (gmtime implementation),
  RStudio [cph, fnd]
Maintainer: Hadley Wickham <hadley@rstudio.com>
Repository: CRAN
Date/Publication: 2020-05-15 16:00:02 UTC
Built: R 4.0.0; x86_64-w64-mingw32; 2020-05-15 16:56:43 UTC; windows
Archs: x64
