# Generated by roxygen2: do not edit by hand

S3method(as.character,bq_job)
S3method(as.character,gs_object)
S3method(as_bq_dataset,BigQueryConnection)
S3method(as_bq_dataset,bq_dataset)
S3method(as_bq_dataset,character)
S3method(as_bq_dataset,list)
S3method(as_bq_field,bq_field)
S3method(as_bq_field,list)
S3method(as_bq_fields,bq_fields)
S3method(as_bq_fields,data.frame)
S3method(as_bq_fields,list)
S3method(as_bq_job,bq_job)
S3method(as_bq_job,character)
S3method(as_bq_job,list)
S3method(as_bq_table,BigQueryConnection)
S3method(as_bq_table,bq_table)
S3method(as_bq_table,character)
S3method(as_bq_table,list)
S3method(as_json,"NULL")
S3method(as_json,bq_field)
S3method(as_json,bq_fields)
S3method(as_json,bq_params)
S3method(format,bq_field)
S3method(format,bq_fields)
S3method(format,gs_object)
S3method(format,size)
S3method(op_can_download,op)
S3method(op_can_download,op_base_remote)
S3method(op_can_download,op_head)
S3method(op_rows,op_base)
S3method(op_rows,op_head)
S3method(op_table,op)
S3method(op_table,op_base_remote)
S3method(print,bq_bytes)
S3method(print,bq_dataset)
S3method(print,bq_field)
S3method(print,bq_fields)
S3method(print,bq_job)
S3method(print,bq_table)
S3method(print,gs_object)
export(as_bq_dataset)
export(as_bq_field)
export(as_bq_fields)
export(as_bq_job)
export(as_bq_table)
export(bigquery)
export(bq_authable)
export(bq_dataset)
export(bq_dataset_create)
export(bq_dataset_delete)
export(bq_dataset_exists)
export(bq_dataset_meta)
export(bq_dataset_query)
export(bq_dataset_tables)
export(bq_dataset_update)
export(bq_field)
export(bq_fields)
export(bq_job)
export(bq_job_meta)
export(bq_job_show_statistics)
export(bq_job_status)
export(bq_job_wait)
export(bq_perform_copy)
export(bq_perform_extract)
export(bq_perform_load)
export(bq_perform_query)
export(bq_perform_upload)
export(bq_project_datasets)
export(bq_project_jobs)
export(bq_project_query)
export(bq_projects)
export(bq_table)
export(bq_table_copy)
export(bq_table_create)
export(bq_table_delete)
export(bq_table_download)
export(bq_table_exists)
export(bq_table_fields)
export(bq_table_load)
export(bq_table_meta)
export(bq_table_nrow)
export(bq_table_save)
export(bq_table_size)
export(bq_table_upload)
export(bq_test_dataset)
export(bq_test_init)
export(bq_test_project)
export(bq_testable)
export(dbi_driver)
export(delete_dataset)
export(delete_table)
export(exists_dataset)
export(exists_table)
export(format_dataset)
export(format_table)
export(get_access_cred)
export(get_dataset)
export(get_job)
export(get_table)
export(gs_test_bucket)
export(gs_test_object)
export(has_access_cred)
export(insert_dataset)
export(insert_extract_job)
export(insert_query_job)
export(insert_table)
export(insert_upload_job)
export(list_datasets)
export(list_projects)
export(list_tabledata)
export(list_tabledata_callback)
export(list_tabledata_iter)
export(list_tables)
export(parse_dataset)
export(parse_table)
export(query_exec)
export(reset_access_cred)
export(set_access_cred)
export(set_oauth2.0_cred)
export(set_service_token)
export(src_bigquery)
export(update_dataset)
export(wait_for)
exportClasses(BigQueryConnection)
exportClasses(BigQueryDriver)
exportClasses(BigQueryResult)
exportMethods(dbBegin)
exportMethods(dbBind)
exportMethods(dbClearResult)
exportMethods(dbColumnInfo)
exportMethods(dbCommit)
exportMethods(dbConnect)
exportMethods(dbDataType)
exportMethods(dbDisconnect)
exportMethods(dbExistsTable)
exportMethods(dbFetch)
exportMethods(dbGetInfo)
exportMethods(dbGetRowCount)
exportMethods(dbGetRowsAffected)
exportMethods(dbGetStatement)
exportMethods(dbHasCompleted)
exportMethods(dbIsValid)
exportMethods(dbListFields)
exportMethods(dbListTables)
exportMethods(dbQuoteIdentifier)
exportMethods(dbQuoteString)
exportMethods(dbReadTable)
exportMethods(dbRemoveTable)
exportMethods(dbRollback)
exportMethods(dbSendQuery)
exportMethods(dbWriteTable)
exportMethods(show)
import(DBI)
import(assertthat)
import(methods)
importFrom(Rcpp,sourceCpp)
importFrom(bit64,integer64)
importFrom(httr,DELETE)
importFrom(httr,GET)
importFrom(httr,PATCH)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,http_status)
importFrom(httr,oauth2.0_token)
importFrom(httr,oauth_app)
importFrom(httr,oauth_endpoint)
importFrom(httr,parse_media)
importFrom(httr,status_code)
importFrom(jsonlite,unbox)
importFrom(tibble,tibble)
useDynLib(bigrquery, .registration = TRUE)
