# Generated by roxygen2: do not edit by hand

S3method(as.character,bq_job)
S3method(as.character,gs_object)
S3method(as_bq_dataset,BigQueryConnection)
S3method(as_bq_dataset,bq_dataset)
S3method(as_bq_dataset,character)
S3method(as_bq_dataset,default)
S3method(as_bq_dataset,list)
S3method(as_bq_field,bq_field)
S3method(as_bq_field,list)
S3method(as_bq_fields,"NULL")
S3method(as_bq_fields,bq_fields)
S3method(as_bq_fields,data.frame)
S3method(as_bq_fields,list)
S3method(as_bq_job,bq_job)
S3method(as_bq_job,character)
S3method(as_bq_job,default)
S3method(as_bq_job,list)
S3method(as_bq_table,BigQueryConnection)
S3method(as_bq_table,bq_table)
S3method(as_bq_table,character)
S3method(as_bq_table,default)
S3method(as_bq_table,list)
S3method(as_json,"NULL")
S3method(as_json,bq_field)
S3method(as_json,bq_fields)
S3method(as_json,bq_param_array)
S3method(as_json,bq_param_scalar)
S3method(as_json,bq_params)
S3method(format,bq_field)
S3method(format,bq_fields)
S3method(format,gs_object)
S3method(op_can_download,lazy_base_query)
S3method(op_can_download,lazy_query)
S3method(op_can_download,lazy_select_query)
S3method(op_can_download,tbl_lazy)
S3method(op_rows,lazy_base_query)
S3method(op_rows,lazy_select_query)
S3method(op_rows,tbl_lazy)
S3method(op_table,lazy_base_remote_query)
S3method(op_table,lazy_query)
S3method(op_table,lazy_select_query)
S3method(op_table,tbl_lazy)
S3method(print,bq_bytes)
S3method(print,bq_dataset)
S3method(print,bq_field)
S3method(print,bq_fields)
S3method(print,bq_job)
S3method(print,bq_param)
S3method(print,bq_params)
S3method(print,bq_table)
S3method(print,gs_object)
S3method(toString,bq_table)
export(as_bq_dataset)
export(as_bq_field)
export(as_bq_fields)
export(as_bq_job)
export(as_bq_table)
export(bigquery)
export(bq_auth)
export(bq_auth_configure)
export(bq_authable)
export(bq_dataset)
export(bq_dataset_create)
export(bq_dataset_delete)
export(bq_dataset_exists)
export(bq_dataset_meta)
export(bq_dataset_query)
export(bq_dataset_tables)
export(bq_dataset_update)
export(bq_deauth)
export(bq_field)
export(bq_fields)
export(bq_has_token)
export(bq_job)
export(bq_job_meta)
export(bq_job_show_statistics)
export(bq_job_status)
export(bq_job_wait)
export(bq_oauth_app)
export(bq_oauth_client)
export(bq_param)
export(bq_param_array)
export(bq_param_scalar)
export(bq_perform_copy)
export(bq_perform_extract)
export(bq_perform_load)
export(bq_perform_query)
export(bq_perform_query_dry_run)
export(bq_perform_upload)
export(bq_project_datasets)
export(bq_project_jobs)
export(bq_project_query)
export(bq_projects)
export(bq_table)
export(bq_table_copy)
export(bq_table_create)
export(bq_table_delete)
export(bq_table_download)
export(bq_table_exists)
export(bq_table_fields)
export(bq_table_load)
export(bq_table_meta)
export(bq_table_nrow)
export(bq_table_patch)
export(bq_table_save)
export(bq_table_size)
export(bq_table_upload)
export(bq_test_dataset)
export(bq_test_init)
export(bq_test_project)
export(bq_testable)
export(bq_token)
export(bq_user)
export(dbi_driver)
export(gs_test_bucket)
export(gs_test_object)
export(src_bigquery)
exportClasses(BigQueryConnection)
exportClasses(BigQueryDriver)
exportClasses(BigQueryResult)
exportMethods(dbAppendTable)
exportMethods(dbBegin)
exportMethods(dbBind)
exportMethods(dbClearResult)
exportMethods(dbColumnInfo)
exportMethods(dbCommit)
exportMethods(dbConnect)
exportMethods(dbCreateTable)
exportMethods(dbDataType)
exportMethods(dbDisconnect)
exportMethods(dbExecute)
exportMethods(dbExistsTable)
exportMethods(dbFetch)
exportMethods(dbGetInfo)
exportMethods(dbGetRowCount)
exportMethods(dbGetRowsAffected)
exportMethods(dbGetStatement)
exportMethods(dbHasCompleted)
exportMethods(dbIsValid)
exportMethods(dbListFields)
exportMethods(dbListTables)
exportMethods(dbQuoteIdentifier)
exportMethods(dbQuoteLiteral)
exportMethods(dbQuoteString)
exportMethods(dbReadTable)
exportMethods(dbRemoveTable)
exportMethods(dbRollback)
exportMethods(dbSendQuery)
exportMethods(dbWriteTable)
exportMethods(show)
import(DBI)
import(methods)
import(rlang, except = unbox)
importFrom(bit64,integer64)
importFrom(gargle,token_fetch)
importFrom(httr,DELETE)
importFrom(httr,GET)
importFrom(httr,PATCH)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,config)
importFrom(httr,content)
importFrom(httr,http_status)
importFrom(httr,parse_media)
importFrom(httr,status_code)
importFrom(jsonlite,unbox)
importFrom(lifecycle,deprecated)
importFrom(tibble,tibble)
useDynLib(bigrquery, .registration = TRUE)
