# bq_check_namespace() works

    Code
      bq_check_namespace("invalid package name", "FIELD_TYPE")
    Condition
      Error in `bq_check_namespace()`:
      ! The package "invalid package name" is required to parse BigQuery 'FIELD_TYPE' fields.

