# error if env var not set

    Code
      bq_test_project()
    Condition
      Error in `bq_test_project()`:
      ! `BIGQUERY_TEST_PROJECT` envvar must to set to a project name.
    Code
      gs_test_bucket()
    Condition
      Error in `gs_test_bucket()`:
      ! `BIGQUERY_TEST_BUCKET` must be set to a bucket name.

